GeneralPurpose

Struct GeneralPurpose 

pub struct GeneralPurpose { /* private fields */ }
A general-purpose base64 engine.

  • It uses no vector CPU instructions, so it will work on any system.
  • It is reasonably fast (~2-3GiB/s).
  • It is not constant-time, though, so it is vulnerable to timing side-channel attacks. For loading cryptographic keys, etc, it is suggested to use the forthcoming constant-time implementation.

Implementations

Source

impl GeneralPurpose

pub const fn new( alphabet: &Alphabet, config: GeneralPurposeConfig, ) -> GeneralPurpose

Create a GeneralPurpose engine from an Alphabet.

While not very expensive to initialize, ideally these should be cached if the engine will be used repeatedly.